package com.ti.mobpo.ui.screens

import com.ti.mobpo.ui.PokeSearchViewModel
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import com.ti.mobpo.R
import com.ti.mobpo.ui.SearchBar
import androidx.lifecycle.viewmodel.compose.viewModel

@Composable
fun PokeSearchScreen(pokeSearchViewModel: PokeSearchViewModel) {
    PokeSearch(pokeSearchViewModel)
}

@Composable
fun PokeSearch(pokeSearchViewModel: PokeSearchViewModel) {
    val searchResults by pokeSearchViewModel.pokemonList.collectAsState()

    Column(
        verticalArrangement = Arrangement.Top,
        horizontalAlignment = Alignment.CenterHorizontally,
        modifier = Modifier
            .fillMaxSize()
            .padding(20.dp)
    ) {
        SearchBar(stringResource(R.string.input_field_label)) { value ->
            pokeSearchViewModel.search(value)
        }

        Spacer(modifier = Modifier.height(16.dp))

        if (searchResults != null) {
            if (searchResults!!.isNotEmpty()) {
                searchResults!!.forEach { pokemon ->
                    Text(text = pokemon.name)
                }
            } else {
                Text("No results found")
            }
        } else {
            Text("Enter a pokemon name to search")
        }
    }
}

@Preview(showBackground = true)
@Composable
fun PokeSearchApp(){
    val pokeSearchViewModel: PokeSearchViewModel = viewModel()
    PokeSearchScreen(pokeSearchViewModel)
}